config_dict = {
    0: 'ul_period',
    1: 'lora_period',
    2: 'pw_stat_period',
    3: 'periodic_pos_period',
    4: 'unknown',
    5: 'geoloc_sensor',
    6: 'geoloc_method',
    7: 'antenna',
    8: 'motion_nb_pos',
    9: 'gps_timeout',
    10: 'agps_timeout',
    11: 'gps_ehpe',
    12: 'gps_convergence',
    13: 'config_flags',
    14: 'transmit_strat',
    15: 'ble_beacon_cnt',
    16: 'ble_beacon_timeout',
    17: 'gps_standby_timeout',
    18: 'confirmed_ul_bitmap',
    19: 'confirmed_ul_retry',
    20: 'motion_sensitivity',
    21: 'shock_detection',
    22: 'periodic_activity_period',
    23: 'motion_duration',
    24: 'geofencing_scan_period',
    25: 'geofencing_collect_period',
    26: 'ble_rssi_filter',
    27: 'temperature_high',
    28: 'temperature_low',
    29: 'temperature_action',
    30: 'transmit_strat_custom',
    31: 'network_timeout_check',
    32: 'network_timeout_reset',
    33: 'collection_scan_type',
    34: 'collection_nb_entry',
    35: 'collection_ble_filter_type',
    36: 'collection_ble_filter_main_1',
    37: 'collection_ble_filter_main_2',
    38: 'collection_ble_filter_sec_value',
    39: 'collection_ble_filter_sec_mask',
    40: 'battery_capacity',
    41: 'reed_switch_configuration',
    42: 'gnss_constellation',
    43: 'prox_scan_pwr_min',
    44: 'prox_distance_coef',
    45: 'prox_scan_frequency',
    46: 'prox_backtrace_max_age',
    47: 'prox_distance_sliding_window',
    48: 'prox_exposure_50',
    49: 'prox_exposure_100',
    50: 'prox_exposure_150',
    51: 'prox_exposure_200',
    52: 'prox_exposure_250',
    53: 'prox_exposure_300',
    54: 'prox_exposure_400',
    55: 'prox_alarm_dist_immediate',
    56: 'prox_alarm_exposure',
    57: 'prox_warn_dist_immediate',
    58: 'prox_warn_exposure',
    59: 'prox_record_dist_immediate',
    60: 'prox_record_exposure',
    61: 'prox_alarm_buz_duration',
    62: 'prox_warn_buz_duration',
    63: 'prox_contact_policy',
    64: 'prox_scan_duration',
    65: 'prox_scan_window',
    66: 'prox_scan_interval',
    67: 'prox_alarm_remanence',
    68: 'prox_warn_remanence',
    69: 'prox_bcn_repeat',
    70: 'prox_bcn_tx_power',
    71: 'prox_reminder_period',
    72: 'prox_reminder_distance',
    73: 'prox_warn_disable_dist',
    74: 'prox_alarm_disable_dist',
    75: 'prox_max_speed_filter',
    76: 'prox_max_update',
    77: 'position_ble_filter_type',
    78: 'position_ble_filter_main_1',
    79: 'position_ble_filter_main_2',
    80: 'position_ble_filter_sec_value',
    81: 'position_ble_filter_sec_mask',
    82: 'position_ble_report_type',
    83: 'buzzer_volume',
    84: 'angle_detect_mode',
    85: 'angle_ref_acq',
    86: 'angle_ref_acc_x',
    87: 'angle_ref_acc_y',
    88: 'angle_ref_acc_z',
    89: 'angle_critical',
    90: 'angle_critical_hyst',
    91: 'angle_report_mode',
    92: 'angle_report_period',
    93: 'angle_report_repeat',
    94: 'angle_rising_time',
    95: 'angle_falling_time',
    96: 'angle_learning_time',
    97: 'angle_acc_accuracy',
    98: 'angle_deviation_delta',
    99: 'angle_deviation_min_interval',
    100: 'angle_deviation_max_interval',
    101: 'default_profile',
    102: 'password',
    103: 'gps_t0_timeout',
    104: 'gps_fix_timeout',
    105: 'geofencing_scan_duration',
    106: 'beaconing_type',
    107: 'beaconing_tx_power',
    108: 'beaconing_static_interval',
    109: 'beaconing_motion_interval',
    110: 'beaconing_motion_duration',
    111: 'ble_cnx_adv_duration',
    112: 'beacon_id_0',
    113: 'beacon_id_1',
    114: 'beacon_id_2',
    115: 'beacon_id_3',
    116: 'beacon_id_4',
    117: 'sos_period',
    118: 'motion_debounce',
    119: 'button_mapping',
    120: 'default_datarate',
    121: 'gps_ehpe_motion',
    122: 'gps_convergence_motion',
    123: 'gps_t0_timeout_motion',
    245: 'ble_cli_active',
    246: 'profile',
    247: 'consumption',
    248: 'ble_bond_info',
    249: 'mode',
    250: 'acc_x_axis',
    251: 'acc_y_axis',
    252: 'acc_z_axis',
    253: 'ble_version',
    254: 'firmware_version',
}
